.. image:: https://img.shields.io/pypi/v/pallur.svg
    :alt: PyPI-Server
    :target: https://pypi.org/project/pallur/
.. image:: https://github.com/clivern/pallur/actions/workflows/ci.yml/badge.svg
    :alt: Build Status
    :target: https://github.com/clivern/pallur/actions/workflows/ci.yml

|

=======
Pallur
=======

A Modern Command Line Tool for Apache Kafka. It is easy to install and use.

To use pallur, follow the following steps:

1. Create a python virtual environment or use system wide environment

.. code-block::

    $ python3 -m venv venv
    $ source venv/bin/activate


2. Install pallur package with pip.

.. code-block::

    $ pip install pallur


3. Get pallur command line help

.. code-block::

    $ pallur --help
